@@ -328,11 +328,12 @@ class Request(object):
 
         objreq = self.reqinfo
         url = objreq['uri']
+        method = objreq.get('method', 'GET')
         parts = urlparse(url)
         host = parts[1]
 
         # Use whole URL in request line per HTTP/1.1 5.1.2 (proxy behavior).
-        requesttext = "GET %s HTTP/1.1\r\n" % url
+        requesttext = "%s %s HTTP/1.1\r\n" % (method, url)
         headers['host'] = host
         # Prevent compression as it's unlikely to survive batching.
         headers['accept-encoding'] = 'identity'
@@ -553,7 +554,7 @@ class BatchClient(httplib2.Http):
 
     """Sort of an HTTP client for performing a batch HTTP request."""
 
-    def __init__(self, endpoint=None):
+    def __init__(self, endpoint=None, **kwargs):
         """Configures the `BatchClient` instance to use the given batch
         processor endpoint.
 
@@ -564,7 +565,7 @@ class BatchClient(httplib2.Http):
 
         """
         self.endpoint = endpoint
-        super(BatchClient, self).__init__()
+        super(BatchClient, self).__init__(**kwargs)
 
     def batch_request(self):
         """Opens a batch request.
